#include "testlib.h"
#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

constexpr int MAXC = 1000 * 1000;

struct Point {
    ll x, y;

    Point(ll x = 0, ll y = 0)
            : x(x)
            , y(y)
    {
    }

    Point operator+(const Point& other) const {
        return Point(x + other.x, y + other.y);
    }

    Point operator-(const Point& other) const {
        return Point(x - other.x, y - other.y);
    }

    ll operator*(const Point& other) const {
        return x * other.y - y * other.x;
    }

    ll operator^(const Point& other) const {
        return x * other.x + y * other.y;
    }
};

bool onLine(const Point& a, const Point& b, const Point& c) {
    return (b - a) * (c - a) == 0;
}

bool operator==(const Point& a, const Point& b) {
    return a.x == b.x && a.y == b.y;
}

bool readAns(InStream& stream, TResult res, const vector<Point>& P) {
    string has = stream.readToken();
    if (has == "No") {
        return false;
    } else if (has != "Yes") {
        quitf(_pe, "Wrong output format, \"Yes\" or \"No\" expected, %s found", has.c_str());
    }

    Point O;
    O.x = stream.readInt(-MAXC, MAXC);
    O.y = stream.readInt(-MAXC, MAXC);

    for (const auto& pt : P) {
        if (pt == O) {
            quitf(res, "Answer point is same as some other point from the set");
        }
    }
    vector<bool> used(P.size(), false);
    vector<int> match(P.size(), false);

    for (int i = 0; i < P.size(); i++) {
        if (!used[i]) {
            for (int j = i + 1; j < P.size(); j++) {
                if (used[j]) continue;
                if (onLine(O, P[i], P[j])) {
                    match[i] = j;
                    match[j] = i;
                    used[i] = true;
                    used[j] = true;
                    break;
                }
            }
            if (!used[i]) {
                quitf(res, "No pair for point %d", i + 1);
            }
        }
    }

    for (int i = 0; i < P.size(); i++) {
        for (int j = 0; j < P.size(); j++) {
            if (i == j || match[i] == j) {
                continue;
            }
            if (onLine(P[i], P[match[i]], P[j])) {
                quitf(res, "Two same lines");
            }
        }
    }

    return true;
}

int main(int argc, char** argv) {
    registerTestlibCmd(argc, argv);

    int n = inf.readInt();
    vector<Point> P(2 * n);
    for (int i = 0; i < 2 * n; i++) {
        P[i].x = inf.readInt();
        P[i].y = inf.readInt();
    }

    auto jans = readAns(ans, _fail, P);
    auto pans = readAns(ouf, _wa, P);

    if (jans && pans) {
        quitf(_ok, "Ok. Both participant and jury found solution");
    } else if (!jans && !pans) {
        quitf(_ok, "Ok. No solution");
    } else if (jans && !pans) {
        quitf(_wa, "Wa. Jury fonud a solution, but particiant didn't");
    } else {
        quitf(_fail, "Fail. Jury didn't find solution, but participant did =(");
    }
    return 0;
}

