// Copyright (C) 2017 Sayutin Dmitry.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; version 3
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; If not, see <http://www.gnu.org/licenses/>.

#include <iostream>
#include <vector>
#include <stdint.h>
#include <algorithm>
#include <set>
#include <map>
#include <array>
#include <queue>
#include <stack>
#include <functional>
#include <utility>
#include <string>
#include <assert.h>
#include <iterator>
#include <cstdint>
#include <cinttypes>
#include <string.h>
#include <random>
#include <numeric>
#include <tuple>
#include <time.h>

using std::cin;
using std::cout;
using std::cerr;

using std::vector;
using std::map;
using std::array;
using std::set;
using std::string;

using std::pair;
using std::make_pair;

using std::min;
using std::abs;
using std::max;

using std::unique;
using std::sort;
using std::generate;
using std::reverse;
using std::min_element;
using std::max_element;

#ifdef LOCAL
#define LASSERT(X) assert(X)
#else
#define LASSERT(X) {}
#endif

template <typename T>
T input() {
    T res;
    cin >> res;
    LASSERT(cin);
    return res;
}

template <typename IT>
void input_seq(IT b, IT e) {
    std::generate(b, e, input<typename std::remove_reference<decltype(*b)>::type>);
}

#define SZ(vec)         int((vec).size())
#define ALL(data)       data.begin(),data.end()
#define RALL(data)      data.rbegin(),data.rend()
#define TYPEMAX(type)   std::numeric_limits<type>::max()
#define TYPEMIN(type)   std::numeric_limits<type>::min()

#define pb push_back
#define eb emplace_back

#define x first
#define y second

int64_t det(int64_t a, int64_t b,
            int64_t c, int64_t d) {
    return a * d - b * c;
}

int64_t cross(pair<int64_t, int64_t> a, pair<int64_t, int64_t> b) {
    return a.x * b.y - a.y * b.x;
}

void make_line(int64_t& a, int64_t& b, int64_t& c, pair<int, int> v, pair<int, int> u) {
    pair<int, int> d = make_pair(v.x - u.x, v.y - u.y);

    a = -d.second;
    b = d.first;
    c = a * v.first + b * v.second;
}

bool check(vector<pair<int, int>>& a, int64_t x, int64_t y) {
    for (auto elem: a)
        if (elem.x == x and elem.y == y)
            return false;

    vector<pair<int64_t, int64_t>> transformed;

    for (auto elem: a)
        if (make_pair(int64_t(elem.y), int64_t(elem.x)) < make_pair(y, x))
            transformed.emplace_back(x - elem.x, y - elem.y);
        else
            transformed.emplace_back(elem.x - x, elem.y - y);

    std::sort(ALL(transformed), [x, y](pair<int, int> v, pair<int, int> u) {
            return cross(v, u) > 0;
        });

    for (int i = 0; i != SZ(transformed) / 2; ++i) {
        auto v = transformed[2 * i];
        auto u = transformed[2 * i + 1];
        
        if (cross(v, u) != 0)
            return false;

        if (i > 0) {
            auto w = transformed[2 * i - 1];
            if (cross(v, w) == 0)
                return false;
        }
    }
    
    return true;
}

int main() {
    std::iostream::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    
    // code here.
    int n = input<int>();
    vector<pair<int, int>> pts(2 * n);

    for (int i = 0; i != 2 * n; ++i)
        cin >> pts[i].x >> pts[i].y;

    if (n == 1) {
        int g = std::__gcd(pts[1].x - pts[0].x, pts[1].y - pts[0].y);

        if (g == 1)
            cout << "No\n";
        else {
            cout << "Yes\n";
            cout << pts[0].x + (pts[1].x - pts[0].x) / g << " " << pts[0].y + (pts[1].y - pts[0].y) / g << "\n";
        }

        return 0;
    }
    
    const double time_limit = 5.9;
    std::mt19937 rnd(31031999);

    std::uniform_int_distribution<int> dst(0, 2 * n - 1);
    
    while (clock() < (long)(time_limit * CLOCKS_PER_SEC)) {
        int a[4];

        for (int i = 0; i != 4; ++i) {
            a[i] = dst(rnd);

            auto ok = [&]() {
                for (int j = 0; j != i; ++j)
                    if (a[j] == a[i])
                        return false;
                return true;
            };
            
            while (not ok())
                a[i] = dst(rnd);
        }

        int64_t a1, b1, c1, a2, b2, c2;

        make_line(a1, b1, c1, pts[a[0]], pts[a[1]]);
        make_line(a2, b2, c2, pts[a[2]], pts[a[3]]);

        int64_t dd = det(a1, b1,
                         a2, b2);

        if (dd == 0)
            continue;
        
        int64_t dx = det(c1, b1,
                         c2, b2);

        int64_t dy = det(a1, c1,
                         a2, c2);

        if (dx % dd == 0 and dy % dd == 0) {
            int64_t x = dx / dd;
            int64_t y = dy / dd;

            if (check(pts, x, y)) {
                cout << "Yes\n";
                cout << x << " " << y << "\n";
                return 0;
            }
        }
    }

    cout << "No\n";
    
    return 0;
}

