#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

constexpr int MAXC = 1000 * 1000;

struct Point {
    ll x, y;

    Point(ll x = 0, ll y = 0)
            : x(x)
            , y(y)
    {
    }

    Point operator+(const Point& other) const {
        return Point(x + other.x, y + other.y);
    }

    Point operator-(const Point& other) const {
        return Point(x - other.x, y - other.y);
    }

    ll operator*(const Point& other) const {
        return x * other.y - y * other.x;
    }

    ll operator^(const Point& other) const {
        return x * other.x + y * other.y;
    }
};

bool operator==(const Point& lhs, const Point& rhs) {
    return lhs.x == rhs.x && lhs.y == rhs.y;
}

bool onLine(const Point& a, const Point& b, const Point& c) {
    return (b - a) * (c - a) == 0;
}

const Point BAD(MAXC + 1, MAXC + 1);
const int MX = 5207;
const ll ADD = 2e18 + 17;
struct Line {
    ll a, b, c;

    Line(const Point& A, const Point& B) {
        a = B.y - A.y;
        b = A.x - B.x;
        c = -(A.x * a + A.y * b);
    }
};

ll gcd(ll x, ll y) {
    if (y == 0) {
        return x;
    }
    return gcd(y, x % y);
}

tuple<ll, ll, ll> getLine(const Point& A, const Point& B) {
    ll a = B.y - A.y;
    ll b = A.x - B.x;
    ll c = -(A.x * a + A.y * b);
    ll g = gcd(gcd(a, b), c);
    a /= g, b /= g, c /= g;
    return min(make_tuple(a, b, c), make_tuple(-a, -b, -c));
}

ll det(ll a, ll b, ll c, ll d) {
    return a * d - b * c;
}

Point intersect(const Line& a, const Line& b) {
    ll dx = det(-a.c, a.b, -b.c, b.b);
    ll dy = det(a.a, -a.c, b.a, -b.c);
    ll d = det(a.a, a.b, b.a, b.b);
    if (d == 0) {
        return BAD;
    }
    if (dx % d != 0 || dy % d != 0) {
        return BAD;
    }
    Point ans(dx / d, dy / d);
    if (ans.x > MAXC || ans.x < -MAXC || ans.y > MAXC || ans.y < -MAXC) {
        return BAD;
    }
    return ans;
}

Point P[MX];

int used[MX];
int match[MX];

int lptr = 0;


namespace Bloom {
    constexpr int SIZE = 5000 * 5000 * 5;
    constexpr int FUNCTIONS = 10;
    int masks[SIZE];
    int P[FUNCTIONS], Q[FUNCTIONS];

    bool isPrime(int x) {
        for (int i = 2; i * i <= x; i++) {
            if (x % i == 0) return false;
        }
        return true;
    }

    void init() {
        vector<int> primes;
        for (int i = SIZE - 1; i >= 0 && primes.size() < 2 * FUNCTIONS; i--) {
            if (isPrime(i)) {
                primes.push_back(i);
            }
        }
        for (int i = 0; i < FUNCTIONS; i++) {
            Q[i] = primes[2 * i];
            P[i] = primes[2 * i + 1];
        }
    }

    int pairToInt(const pair<int, int>& a) {
        return (((a.first << 13) | a.second) << 1) | 1;
    }

    pair<int, int> intToPair(int x) {
        if (!(x & 1)) {
            return {-1, -1};
        }
        x >>= 1;
        return {x >> 13, x & ((1 << 13) - 1)};
    }

    int hashIt(const tuple<ll, ll, ll>& t, int id) {
        int p = P[id], q = Q[id];
        ll a = get<0>(t), b = get<1>(t), c = get<2>(t);
        int ans = ((((ll)a * p + b) % q) * p + c) % q;
        if (ans < 0) {
            ans += q;
        }
        return ans;
    }

    pair<int, int> get(const tuple<ll, ll, ll>& key) {
        int ans = (1 << 30) - 1;
        for (int i = 0; i < FUNCTIONS; i++) {
            int hash = hashIt(key, i);
            ans &= masks[hash];
        }
        return intToPair(ans);
    }

    void add(const tuple<ll, ll, ll>& key, const pair<int, int>& value) {
        int val = pairToInt(value);
        if (get(key).first != -1) return;
        for (int i = 0; i < FUNCTIONS; i++) {
            int hash = hashIt(key, i);
            masks[hash] |= val;
        }
    }
};

int main() {
    srand(42123);

    int n;
    cin >> n;
    n *= 2;
    set<pair<ll, ll> > spts;
    for (int i = 0; i < n; i++) {
        cin >> P[i].x >> P[i].y;
        spts.emplace(P[i].x, P[i].y);
    }

    random_shuffle(P, P + n);

    Bloom::init();
    for (int i = 0; i < n; i++) {
        for (int j = i + 1; j < n; j++) {
            auto line = getLine(P[i], P[j]);
    //        fprintf(stderr, "Line %lld %lld %lld Pts: %d %d\n", get<0>(line), get<1>(line), get<2>(line), i, j);
            Bloom::add(line, {i, j});
        }
    }

    int a = 0;
    int iter = 0;
    for (int b = 0; b < n; b++) {
        int c = 1;
        if (b == c) c++;
        for (int d = 0; d < n; d++) {
            if (d == a || d == b || d == c) continue;
            Point O = intersect(Line(P[a], P[b]), Line(P[c], P[d]));
            if (O == BAD) {
                continue;
            }
            if (spts.count({O.x, O.y})) {
                continue;
            }
            iter++;
            used[a] = used[b] = used[c] = used[d] = iter;
            bool ok = true;
            for (int i = 0; i < n; i++) {
                if (used[i] == iter) continue;
                auto line = getLine(P[i], O);
                auto pts = Bloom::get(line);

                if (pts.first == -1) {
                    ok = false;
                    continue;
                }
               // fprintf(stderr, "AFTER Line %lld %lld %lld Pts: %d %d\n", get<0>(line), get<1>(line), get<2>(line), pts.first, pts.second);

                int v = -1;
                if (pts.first != i) {
                    if (pts.second != i) {
                        ok = false;
                        break;
                    } else {
                        v = pts.first;
                    }
                } else {
                    v = pts.second;
                }

                if (used[v] == iter) {
                    ok = false;
                    break;
                }

                used[v] = iter;
                used[i] = iter;
            }

            if (ok) {
                cout << "Yes" << endl;
                cout << O.x << " " << O.y << endl;
                return 0;
            }
        }
    }
    cout << "No" << endl;
}

