#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

constexpr int MAXC = 1000 * 1000;

struct Point {
    ll x, y;

    Point(ll x = 0, ll y = 0)
            : x(x)
            , y(y)
    {
    }

    Point operator+(const Point& other) const {
        return Point(x + other.x, y + other.y);
    }

    Point operator-(const Point& other) const {
        return Point(x - other.x, y - other.y);
    }

    ll operator*(const Point& other) const {
        return x * other.y - y * other.x;
    }

    ll operator^(const Point& other) const {
        return x * other.x + y * other.y;
    }
};

bool operator==(const Point& lhs, const Point& rhs) {
    return lhs.x == rhs.x && lhs.y == rhs.y;
}

bool onLine(const Point& a, const Point& b, const Point& c) {
    return (b - a) * (c - a) == 0;
}

const Point BAD(MAXC + 1, MAXC + 1);
const int MX = 5207;

struct Line {
    ll a, b, c;

    Line(const Point& A, const Point& B) {
        a = B.y - A.y;
        b = A.x - B.x;
        c = -(A.x * a + A.y * b);
    }
};

ll gcd (ll a, ll b) {
	while (b) {
		a %= b;
		swap (a, b);
	}
	return a;
}


tuple<ll, ll, ll> getLine(const Point& A, const Point& B) {
    ll a = B.y - A.y;
    ll b = A.x - B.x;
    ll c = -(A.x * a + A.y * b);
    ll g = gcd(gcd(a, b), c);
    a /= g, b /= g, c /= g;
    return min(make_tuple(a, b, c), make_tuple(-a, -b, -c));
}

ll det(ll a, ll b, ll c, ll d) {
    return a * d - b * c;
}

Point intersect(const Line& a, const Line& b) {
    ll dx = det(-a.c, a.b, -b.c, b.b);
    ll dy = det(a.a, -a.c, b.a, -b.c);
    ll d = det(a.a, a.b, b.a, b.b);
    if (d == 0) {
        return BAD;
    }
    if (dx % d != 0 || dy % d != 0) {
        return BAD;
    }
    Point ans(dx / d, dy / d);
    if (ans.x > MAXC || ans.x < -MAXC || ans.y > MAXC || ans.y < -MAXC) {
        return BAD;
    }
    return ans;
}

Point P[MX];

int used[MX];
int match[MX];

tuple<int, int, ll, int, int> lines[5200 * 5200 / 2];
int lptr = 0;
int main() {
    srand(42123);

    int n;
    cin >> n;
    n *= 2;
    set<pair<ll, ll> > spts;
    for (int i = 0; i < n; i++) {
        cin >> P[i].x >> P[i].y;
        spts.emplace(P[i].x, P[i].y);
    }

    random_shuffle(P, P + n);

    for (int i = 0; i < n; i++) {
        for (int j = i + 1; j < n; j++) {
            auto line = getLine(P[i], P[j]);
            lines[lptr++] = make_tuple(get<0>(line), get<1>(line), get<2>(line), i, j);
        }
    }

    sort(lines, lines + lptr);

    int a = 0;
    int iter = 0;
    for (int b = 0; b < n; b++) {
        int c = 1;
        if (b == c) c++;
        for (int d = 0; d < n; d++) {
            if (d == a || d == b || d == c) continue;
            Point O = intersect(Line(P[a], P[b]), Line(P[c], P[d]));
            if (O == BAD) {
                continue;
            }
            if (spts.count({O.x, O.y})) {
                continue;
            }
            iter++;
            used[a] = used[b] = used[c] = used[d] = iter;
            bool ok = true;
            for (int i = 0; i < n; i++) {
                if (used[i] == iter) continue;
                auto line = getLine(P[i], O);
                int pos = lower_bound(lines, lines + lptr, make_tuple(get<0>(line), get<1>(line), get<2>(line), -1, -1)) - lines;
                if (pos == lptr) {
                    ok = false;
                    break;
                }

                auto tup = lines[pos];
                auto fndline = make_tuple(get<0>(tup), get<1>(tup), get<2>(tup));
                auto pts = make_pair(get<3>(tup), get<4>(tup));

                if (fndline != line) {
                    ok = false;
                    break;
                }

                int v = -1;
                if (pts.first != i) {
                    if (pts.second != i) {
                        ok = false;
                        break;
                    } else {
                        v = pts.first;
                    }
                } else {
                    v = pts.second;
                }

                if (used[v] == iter) {
                    ok = false;
                    break;
                }

                used[v] = iter;
                used[i] = iter;
            }

            if (ok) {
                cout << "Yes" << endl;
                cout << O.x << " " << O.y << endl;
                return 0;
            }
        }
    }
    cout << "No" << endl;
}

