#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

constexpr int MAXC = 1000 * 1000;

struct Point {
    ll x, y;

    Point(ll x = 0, ll y = 0)
            : x(x)
            , y(y)
    {
    }

    Point operator+(const Point& other) const {
        return Point(x + other.x, y + other.y);
    }

    Point operator-(const Point& other) const {
        return Point(x - other.x, y - other.y);
    }

    ll operator*(const Point& other) const {
        return x * other.y - y * other.x;
    }

    ll operator^(const Point& other) const {
        return x * other.x + y * other.y;
    }
};

bool operator==(const Point& lhs, const Point& rhs) {
    return lhs.x == rhs.x && lhs.y == rhs.y;
}

bool onLine(const Point& a, const Point& b, const Point& c) {
    return (b - a) * (c - a) == 0;
}

const Point BAD(MAXC + 1, MAXC + 1);
const int MX = 5207;

struct Line {
    ll a, b, c;

    Line(const Point& A, const Point& B) {
        a = B.y - A.y;
        b = A.x - B.x;
        c = -(A.x * a + A.y * b);
    }
};

ll gcd(ll x, ll y) {
    if (y == 0) {
        return x;
    }
    return gcd(y, x % y);
}

tuple<ll, ll, ll> getLine(const Point& A, const Point& B) {
    ll a = B.y - A.y;
    ll b = A.x - B.x;
    ll c = -(A.x * a + A.y * b);
    ll g = gcd(gcd(a, b), c);
    a /= g, b /= g, c /= g;
    return min(make_tuple(a, b, c), make_tuple(-a, -b, -c));
}

ll det(ll a, ll b, ll c, ll d) {
    return a * d - b * c;
}

Point intersect(const Line& a, const Line& b) {
    ll dx = det(-a.c, a.b, -b.c, b.b);
    ll dy = det(a.a, -a.c, b.a, -b.c);
    ll d = det(a.a, a.b, b.a, b.b);
    if (d == 0) {
        return BAD;
    }
    if (dx % d != 0 || dy % d != 0) {
        return BAD;
    }
    Point ans(dx / d, dy / d);
    if (ans.x > MAXC || ans.x < -MAXC || ans.y > MAXC || ans.y < -MAXC) {
        return BAD;
    }
    return ans;
}

Point P[MX];

int used[MX];
int match[MX];

const int ML = 5000 * 5000 / 2;

tuple<int, int, ll, int, int> lines[ML];
int perm[ML], nperm[ML];
int cnt[ML];
const int MOD = 2000 * 1000;
const int MAXSZ = 4000 * 1000;

int lptr = 0;
int main() {
    srand(42123);

    int n;
    cin >> n;
    n *= 2;
    set<pair<ll, ll> > spts;
    for (int i = 0; i < n; i++) {
        cin >> P[i].x >> P[i].y;
        spts.emplace(P[i].x, P[i].y);
    }

    random_shuffle(P, P + n);

    for (int i = 0; i < n; i++) {
        for (int j = i + 1; j < n; j++) {
            auto line = getLine(P[i], P[j]);
            lines[lptr++] = make_tuple(get<0>(line), get<1>(line), get<2>(line), i, j);
        }
    }

    for (int i = 0; i < lptr; i++) {
        perm[i] = i;
    }

    {
        memset(cnt, 0, sizeof(cnt));
        int minVal = 1e9, maxVal = -1e9;
        for (int i = 0; i < lptr; i++) {
            minVal = min(minVal, (int)(get<2>(lines[perm[i]]) % MOD));
            maxVal = max(maxVal, (int)(get<2>(lines[perm[i]]) % MOD));
        }
        assert(maxVal - minVal < MAXSZ);
        for (int i = 0; i < lptr; i++) {
            int x = get<2>(lines[perm[i]]) % MOD - minVal;
            cnt[x]++;
        }
        for (int i = 1; i <= maxVal - minVal + 1; i++) {
            cnt[i] += cnt[i - 1];
        }
        for (int i = lptr - 1; i >= 0; i--) {
            int x = get<2>(lines[perm[i]]) % MOD - minVal;
            cnt[x]--;
            nperm[cnt[x]] = perm[i];
        }
        memcpy(perm, nperm, sizeof(perm));
    }

    {
        memset(cnt, 0, sizeof(cnt));
        int minVal = 1e9, maxVal = -1e9;
        for (int i = 0; i < lptr; i++) {
            minVal = min(minVal, (int)(get<2>(lines[perm[i]]) / MOD));
            maxVal = max(maxVal, (int)(get<2>(lines[perm[i]]) / MOD));
        }
        assert(maxVal - minVal < MAXSZ);
        for (int i = 0; i < lptr; i++) {
            int x = get<2>(lines[perm[i]]) / MOD - minVal;
            cnt[x]++;
        }
        for (int i = 1; i <= maxVal - minVal + 1; i++) {
            cnt[i] += cnt[i - 1];
        }
        for (int i = lptr - 1; i >= 0; i--) {
            int x = get<2>(lines[perm[i]]) / MOD - minVal;
            cnt[x]--;
            nperm[cnt[x]] = perm[i];
        }
        memcpy(perm, nperm, sizeof(perm));
    }

    for (int i = 1; i < lptr;  i++) {
        assert(get<2>(lines[perm[i]]) >= get<2>(lines[perm[i - 1]]));
    }

    {
        memset(cnt, 0, sizeof(cnt));
        int minVal = 1e9, maxVal = -1e9;
        for (int i = 0; i < lptr; i++) {
            minVal = min(minVal, get<1>(lines[perm[i]]));
            maxVal = max(maxVal, get<1>(lines[perm[i]]));
        }
        assert(maxVal - minVal < MAXSZ);
        for (int i = 0; i < lptr; i++) {
            int x = get<1>(lines[perm[i]]) - minVal;
            cnt[x]++;
        }
        for (int i = 1; i <= maxVal - minVal + 1; i++) {
            cnt[i] += cnt[i - 1];
        }
        for (int i = lptr - 1; i >= 0; i--) {
            int x = get<1>(lines[perm[i]]) - minVal;
            cnt[x]--;
            nperm[cnt[x]] = perm[i];
        }
        memcpy(perm, nperm, sizeof(perm));
    }

    for (int i = 1; i < lptr;  i++) {
        assert(make_pair(get<1>(lines[perm[i]]), get<2>(lines[perm[i]])) >= make_pair(get<1>(lines[perm[i - 1]]), get<2>(lines[perm[i - 1]])));
    }

    {
        memset(cnt, 0, sizeof(cnt));
        int minVal = 1e9, maxVal = -1e9;
        for (int i = 0; i < lptr; i++) {
            minVal = min(minVal, get<0>(lines[perm[i]]));
            maxVal = max(maxVal, get<0>(lines[perm[i]]));
        }
        assert(maxVal - minVal < MAXSZ);
        for (int i = 0; i < lptr; i++) {
            int x = get<0>(lines[perm[i]]) - minVal;
            cnt[x]++;
        }
        for (int i = 1; i <= maxVal - minVal + 1; i++) {
            cnt[i] += cnt[i - 1];
        }
        for (int i = lptr - 1; i >= 0; i--) {
            int x = get<0>(lines[perm[i]]) - minVal;
            cnt[x]--;
            nperm[cnt[x]] = perm[i];
        }
        memcpy(perm, nperm, sizeof(perm));
    }

    for (int i = 1; i < lptr;  i++) {
        assert(make_tuple(get<0>(lines[perm[i]]), get<1>(lines[perm[i]]), get<2>(lines[perm[i]])) >= make_tuple(get<0>(lines[perm[i - 1]]), get<1>(lines[perm[i - 1]]), get<2>(lines[perm[i - 1]])));
    }

    int a = 0;
    int iter = 0;
    for (int b = 0; b < n; b++) {
        int c = 1;
        if (b == c) c++;
        for (int d = 0; d < n; d++) {
            if (d == a || d == b || d == c) continue;
            Point O = intersect(Line(P[a], P[b]), Line(P[c], P[d]));
            if (O == BAD) {
                continue;
            }
            if (spts.count({O.x, O.y})) {
                continue;
            }
            iter++;
            used[a] = used[b] = used[c] = used[d] = iter;
            bool ok = true;
            for (int i = 0; i < n; i++) {
                if (used[i] == iter) continue;
                auto line = getLine(P[i], O);
                auto cline = make_tuple(get<0>(line), get<1>(line), get<2>(line), -1, -1);
                int lg = 0, rg = lptr;
                while (rg - lg > 1) {
                    int mg = (lg + rg) >> 1;
                    if (lines[perm[mg]] <= cline) {
                        lg = mg;
                    } else {
                        rg = mg;
                    }
                }

                if (rg == lptr) {
                    ok = false;
                    break;
                }
                auto tup = lines[perm[rg]];
                auto fndline = make_tuple(get<0>(tup), get<1>(tup), get<2>(tup));
                auto pts = make_pair(get<3>(tup), get<4>(tup));

                if (fndline != line) {
                    ok = false;
                    break;
                }

                int v = -1;
                if (pts.first != i) {
                    if (pts.second != i) {
                        ok = false;
                        break;
                    } else {
                        v = pts.first;
                    }
                } else {
                    v = pts.second;
                }

                if (used[v] == iter) {
                    ok = false;
                    break;
                }

                used[v] = iter;
                used[i] = iter;
            }

            if (ok) {
                cout << "Yes" << endl;
                cout << O.x << " " << O.y << endl;
                return 0;
            }
        }
    }
    cout << "No" << endl;
}

