#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

constexpr int MAXC = 1000 * 1000;

struct Point {
    ll x, y;

    Point(ll x = 0, ll y = 0)
            : x(x)
            , y(y)
    {
    }

    Point operator+(const Point& other) const {
        return Point(x + other.x, y + other.y);
    }

    Point operator-(const Point& other) const {
        return Point(x - other.x, y - other.y);
    }

    ll operator*(const Point& other) const {
        return x * other.y - y * other.x;
    }

    ll operator^(const Point& other) const {
        return x * other.x + y * other.y;
    }
};

bool operator==(const Point& lhs, const Point& rhs) {
    return lhs.x == rhs.x && lhs.y == rhs.y;
}

bool onLine(const Point& a, const Point& b, const Point& c) {
    return (b - a) * (c - a) == 0;
}

const Point BAD(MAXC + 1, MAXC + 1);
const int MX = 5207;

struct Line {
    ll a, b, c;

    Line(const Point& A, const Point& B) {
        a = B.y - A.y;
        b = A.x - B.x;
        c = -(A.x * a + A.y * b);
    }
};

ll det(ll a, ll b, ll c, ll d) {
    return a * d - b * c;
}

Point intersect(const Line& a, const Line& b) {
    ll dx = det(-a.c, a.b, -b.c, b.b);
    ll dy = det(a.a, -a.c, b.a, -b.c);
    ll d = det(a.a, a.b, b.a, b.b);
    if (d == 0) {
        return BAD;
    }
    if (dx % d != 0 || dy % d != 0) {
        return BAD;
    }
    Point ans(dx / d, dy / d);
    if (ans.x > MAXC || ans.x < -MAXC || ans.y > MAXC || ans.y < -MAXC) {
        return BAD;
    }
    return ans;
}

Point P[MX];

int used[MX];
int match[MX];
int main() {
    srand(42123);

    int n;
    cin >> n;
    n *= 2;
    set<pair<ll, ll> > spts;

    for (int i = 0; i < n; i++) {
        cin >> P[i].x >> P[i].y;
        spts.emplace(P[i].x, P[i].y);
    }

    random_shuffle(P, P + n);

    int iter = 0;

    for (int a = 0; a < n; a++) {
        for (int b = a + 1; b < n; b++) {
            for (int c = 0; c < n; c++) {
                if (a == c || b == c) continue;
                for (int d = c + 1; d < n; d++) {
                    if (a == d || b == d) continue;
                    Point O = intersect(Line(P[a], P[b]), Line(P[c], P[d]));
                    if (O == BAD) continue;
                    iter++;
                    used[a] = used[b] = used[c] = used[d] = iter;
                    match[a] = b;
                    match[b] = a;
                    match[c] = d;
                    match[d] = c;
                    bool ok = true;
                    for (int u = 0; u < n; u++) {
                        if (used[u] == iter) continue;
                        for (int v = u + 1; v < n; v++) {
                            if (used[v] == iter) continue;
                            if (onLine(P[u], P[v], O)) {
                                used[u] = used[v] = iter;
                                match[u] = v;
                                match[v] = u;
                                break;
                            }
                        }
                        if (used[u] != iter) {
                            ok = false;
                        }
                    }
                    if (!ok) continue;
                    for (int u = 0; u < n; u++) {
                        int pu = match[u];
                        for (int v = 0; v < n; v++) {
                            if (u == v || pu == v) continue;
                            if (onLine(P[u], P[pu], P[v])) {
                                ok = false;
                            }
                        }
                    }
                    if (ok) {
                        cout << "Yes" << endl;
                        cout << O.x << " " << O.y << endl;
                        return 0;
                    }
                }
            }
        }
    }
    cout << "No" << endl;
}

